..  Copyright (C)  Mark Guzdial, Barbara Ericson, Briana Morrison
    Permission is granted to copy, distribute and/or modify this document
    under the terms of the GNU Free Documentation License, Version 1.3 or
    any later version published by the Free Software Foundation; with
    Invariant Sections being Forward, Prefaces, and Contributor List,
    no Front-Cover Texts, and no Back-Cover Texts.  A copy of the license
    is included in the section entitled "GNU Free Documentation License".

Image Chaper Summary
============================

This chapter included the following concepts from computing.

..	index::
    single: loop body
    single: for loop
	single: pixel
	single: nested loop

- **Class** - We worked with the Image and Pixel classes.  An image object has pixel objects.  Each pixel object has a color which is made up of red, green, and blue values.
- **For Loop** - A ``for`` loop is a programming statement that tells the computer to repeat a statement or a set of statements (**which are the body of the loop**). It will repeat a specific number of times.
- **Image** - An object that represents an image or picture on a computer.  An image has pixels arranged in a rectangular block.
- **Loop Body** - The statement or statements that are repeated in a loop.  In Python indention is used to show what statements are part of the body of a loop.
- **Nested Loop** - A nested loop has one loop inside the body of another loop.
- **Pixel** - A pixel is one small part (element) of an image (picture).  Pixels are stored in a grid and have both a x (horizontal) and y (vertical) value.  A pixel has a color which can be defined by an amount of red, green, and blue with values from 0 to 255.
